@@ -29,7 +29,7 @@ class DesktopPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
     public:
-        void registerTypes(const char *uri) Q_DECL_OVERRIDE;
+        void registerTypes(const char *uri) override;
 };
 
 #endif // DESKTOPPLUGIN_H
