@@ -45,6 +45,7 @@ class SwitcherBackend : public QObject {
     Q_OBJECT
 
     Q_PROPERTY(bool shouldShowSwitcher READ shouldShowSwitcher WRITE setShouldShowSwitcher NOTIFY shouldShowSwitcherChanged)
+    Q_PROPERTY(bool dropEnabled READ dropEnabled CONSTANT)
 
 
 public:
@@ -69,6 +70,12 @@ public Q_SLOTS:
     void setCurrentActivity(const QString &activity);
     void stopActivity(const QString &activity);
 
+    void setDropMode(bool value);
+    void drop(QMimeData* mimeData, int modifiers, const QVariant &activityId);
+    void dropCopy(QMimeData* mimeData, const QVariant &activityId);
+    void dropMove(QMimeData* mimeData, const QVariant &activityId);
+    bool dropEnabled() const;
+
 private:
     template <typename Handler>
     inline void registerShortcut(const QString &actionName, const QString &name,
@@ -99,6 +106,9 @@ private:
     QTimer m_modKeyPollingTimer;
     QString m_previousActivity;
 
+    bool m_dropModeActive;
+    QTimer m_dropModeHider;
+
     SortedActivitiesModel *m_runningActivitiesModel = nullptr;
     SortedActivitiesModel *m_stoppedActivitiesModel = nullptr;
 
