@@ -22,7 +22,7 @@
 #include "componentchooserfilemanager.h"
 #include <kprocess.h>
 #include <kmimetypetrader.h>
-#include <KServiceTypeTrader>
+#include <KApplicationTrader>
 #include <kopenwithdialog.h>
 #include <kconfiggroup.h>
 #include <QStandardPaths>
@@ -78,12 +78,16 @@ void CfgFileManager::load(KConfig *)
 
     const KService::Ptr fileManager = KMimeTypeTrader::self()->preferredService(mime);
 
-    const auto constraint = QStringLiteral("'FileManager' in Categories and 'inode/directory' in ServiceTypes");
-    const KService::List fileManagers = KServiceTypeTrader::self()->query(QStringLiteral("Application"), constraint);
+    const auto fileManagers = KApplicationTrader::query([] (const KService::Ptr &service) {
+        if (service->exec().isEmpty()) {
+            return false;
+        }
+        return service->categories().contains("FileManager");
+    });
     for (const KService::Ptr &service : fileManagers) {
         addItem(QIcon::fromTheme(service->icon()), service->name(), service->storageId());
 
-        if (fileManager->storageId() == service->storageId()) {
+        if (fileManager && fileManager->storageId() == service->storageId()) {
             setCurrentIndex(count() -1);
             m_currentIndex = count() -1;
         }
@@ -93,7 +97,7 @@ void CfgFileManager::load(KConfig *)
     }
 
     // in case of a service not associated with FileManager Category
-    if (m_currentIndex == -1 && !fileManager->storageId().isEmpty()) {
+    if (m_currentIndex == -1 && fileManager && !fileManager->storageId().isEmpty()) {
         const KService::Ptr service = KService::serviceByStorageId(fileManager->storageId());
 
         const QString icon = !service->icon().isEmpty() ? service->icon() : QStringLiteral("application-x-shellscript");
