@@ -233,11 +233,7 @@ void EmoticonList::selectTheme()
 
         new QListWidgetItem(QIcon(it.key()), text, emoList);
     }
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-    emit changed();
-#else
     emit markAsChanged();
-#endif
 }
 
 void EmoticonList::btRemoveThemeClicked()
@@ -307,11 +303,7 @@ void EmoticonList::addEmoticon()
     if (theme.addEmoticon(dlg->getEmoticon(), dlg->getText(), KEmoticonsProvider::Copy)) {
         new QListWidgetItem(QPixmap(dlg->getEmoticon()), dlg->getText(), emoList);
         themeList->currentItem()->setIcon(QIcon(previewEmoticon(theme)));
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-        emit changed();
-#else
         emit markAsChanged();
-#endif
     }
     delete dlg;
 }
@@ -364,11 +356,7 @@ void EmoticonList::editEmoticon()
         new QListWidgetItem(QPixmap(emo), dlg->getText(), emoList);
     }
 
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 64, 0)
-    emit changed();
-#else
     emit markAsChanged();
-#endif
     delete dlg;
 }
 
