@@ -26,11 +26,13 @@
 #include <Solid/DeviceNotifier>
 #include <Solid/Device>
 #include <Solid/StorageVolume>
+#include <Solid/StorageAccess>
 
 #include "AutomounterSettings.h"
 
-DeviceModel::DeviceModel(QObject *parent)
+DeviceModel::DeviceModel(AutomounterSettings *m_settings, QObject *parent)
     : QAbstractItemModel(parent)
+    , m_settings(m_settings)
 {
     reload();
     
@@ -60,8 +62,8 @@ QVariant DeviceModel::headerData(int section, Qt::Orientation orientation, int r
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch(section) {
         case 0: return i18n("Device");
-        case 1: return i18n("Automount on Login");
-        case 2: return i18n("Automount on Attach");
+        case 1: return i18nc("As in automount on login", "On Login");
+        case 2: return i18nc("As in automoount on attach", "On Attach");
         }
     }
     return QVariant();
@@ -93,35 +95,46 @@ void DeviceModel::deviceRemoved(const QString &udi)
         m_attached.removeOne(udi);
         endRemoveRows();
 
-        // NOTE the device is not moved to the "Disconnected" section
-        // when removing it while the KCM is opened because we need to check
-        // whether the device that just got detached is ignored
+        // We move the device to the "Disconnected" section only if it
+        // is a known device, meaning we have some setting for this device.
+        // Otherwise the device is not moved to the "Disconnected" section
+        // because we need to check whether the device that just got detached is ignored
         // (don't show partition tables and other garbage) but this information
-        // is no longer available when the device is gone
+        // is no longer available once the device is gone
+        if (m_settings->knownDevices().contains(udi)) {
+            beginInsertRows(index(1, 0), m_disconnected.size(), m_disconnected.size());
+            m_disconnected << udi;
+            endInsertRows();
+        }
     }
 }
 
 void DeviceModel::addNewDevice(const QString &udi)
 {
-    AutomounterSettings::self()->load();
+    m_settings->load();
 
     if (!m_loginForced.contains(udi)) {
-        m_loginForced[udi] = AutomounterSettings::deviceAutomountIsForced(udi, AutomounterSettings::Login);
+        m_loginForced[udi] = m_settings->deviceAutomountIsForced(udi, AutomounterSettings::Login);
     }
     if (!m_attachedForced.contains(udi)) {
-        m_loginForced[udi] = AutomounterSettings::deviceAutomountIsForced(udi, AutomounterSettings::Attach);
+        m_loginForced[udi] = m_settings->deviceAutomountIsForced(udi, AutomounterSettings::Attach);
     }
 
     const Solid::Device dev(udi);
     if (dev.isValid()) {
-        beginInsertRows(index(0, 0), m_attached.size(), m_attached.size());
-        m_attached << udi;
+        if (dev.is<Solid::StorageAccess>()) {
+            const Solid::StorageAccess *access = dev.as<Solid::StorageAccess>();
+            if (!access->isIgnored() || !access->isAccessible()) {
+                beginInsertRows(index(0, 0), m_attached.size(), m_attached.size());
+                m_attached << udi;
+                endInsertRows();
+            }
+        }
     } else {
         beginInsertRows(index(1, 0), m_disconnected.size(), m_disconnected.size());
         m_disconnected << udi;
+        endInsertRows();
     }
-
-    endInsertRows();
 }
 
 void DeviceModel::reload()
@@ -132,12 +145,17 @@ void DeviceModel::reload()
     m_attached.clear();
     m_disconnected.clear();
 
-    foreach (const QString &dev, AutomounterSettings::knownDevices()) {
+    m_automaticLogin = m_settings->automountOnLogin();
+    m_automaticAttached = m_settings->automountOnPlugin();
+
+    const auto knownDevices = m_settings->knownDevices();
+    for (const QString &dev : knownDevices) {
         addNewDevice(dev);
     }
-    foreach (const QString &udi, m_loginForced.keys()) {
-        m_loginForced[udi] = AutomounterSettings::deviceAutomountIsForced(udi, AutomounterSettings::Login);
-        m_attachedForced[udi] = AutomounterSettings::deviceAutomountIsForced(udi, AutomounterSettings::Attach);
+    const auto keys = m_loginForced.keys();
+    for (const QString &udi : keys) {
+        m_loginForced[udi] = m_settings->deviceAutomountIsForced(udi, AutomounterSettings::Login);
+        m_attachedForced[udi] = m_settings->deviceAutomountIsForced(udi, AutomounterSettings::Attach);
     }
     endResetModel();
 }
@@ -178,19 +196,44 @@ QModelIndex DeviceModel::parent(const QModelIndex &index) const
 
 Qt::ItemFlags DeviceModel::flags(const QModelIndex &index) const
 {
-    if (index.isValid()) {
-        if (index.parent().isValid()) {
-            if (index.column() > 0) {
-                return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
-            } else if (index.column() == 0) {
-                return Qt::ItemIsSelectable | Qt::ItemIsEnabled;
-            }
+    if (!index.isValid()) {
+        return Qt::NoItemFlags;
+    }
+
+    if (!index.parent().isValid()) {
+        // first child section elements
+        if (m_automaticLogin && m_automaticAttached) {
+            return Qt::NoItemFlags;
         } else {
             return Qt::ItemIsEnabled;
         }
     }
 
-    return Qt::NoItemFlags;
+    switch (index.column()) {
+    case 0:
+        // first column
+        if (m_automaticLogin && m_automaticAttached) {
+            return Qt::NoItemFlags;
+        } else {
+            return Qt::ItemIsEnabled;
+        }
+    case 1:
+        // on login column
+        if (m_automaticLogin) {
+            // automount on login was checked
+            return Qt::ItemIsSelectable | Qt::ItemIsUserCheckable;
+        }
+        return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
+    case 2:
+        // on attached column
+        if (m_automaticAttached) {
+            // automount on attach was checked
+            return Qt::ItemIsSelectable | Qt::ItemIsUserCheckable;
+        }
+        return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
+    default:
+        Q_UNREACHABLE();
+    }
 }
 
 bool DeviceModel::setData(const QModelIndex &index, const QVariant &value, int role)
@@ -241,7 +284,7 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
                 case Qt::CheckStateRole:
                     return m_loginForced[udi] ? Qt::Checked : Qt::Unchecked;
                 case Qt::ToolTipRole:
-                    if (m_loginForced[udi] || AutomounterSettings::shouldAutomountDevice(udi, AutomounterSettings::Login))
+                    if (m_loginForced[udi] || m_settings->shouldAutomountDevice(udi, AutomounterSettings::Login))
                         return i18n("This device will be automatically mounted at login.");
                     return i18n("This device will not be automatically mounted at login.");
                 }
@@ -250,7 +293,7 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
                 case Qt::CheckStateRole:
                     return m_attachedForced[udi] ? Qt::Checked : Qt::Unchecked;
                 case Qt::ToolTipRole:
-                    if (m_attachedForced[udi] || AutomounterSettings::shouldAutomountDevice(udi, AutomounterSettings::Attach))
+                    if (m_attachedForced[udi] || m_settings->shouldAutomountDevice(udi, AutomounterSettings::Attach))
                         return i18n("This device will be automatically mounted when attached.");
                     return i18n("This device will not be automatically mounted when attached.");
                 }
@@ -269,18 +312,18 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
             if (index.column() == 0) {
                 switch(role) {
                 case Qt::DisplayRole:
-                    return AutomounterSettings::getDeviceName(udi);
+                    return m_settings->getDeviceName(udi);
                 case Qt::ToolTipRole:
                     return i18n("UDI: %1", udi);
                 case Qt::DecorationRole:
-                    return QIcon::fromTheme(AutomounterSettings::getDeviceIcon(udi));
+                    return QIcon::fromTheme(m_settings->getDeviceIcon(udi));
                 }
             } else if (index.column() == 1) {
                 switch(role) {
                 case Qt::CheckStateRole:
                     return m_loginForced[udi] ? Qt::Checked : Qt::Unchecked;
                 case Qt::ToolTipRole:
-                    if (m_loginForced[udi] || AutomounterSettings::shouldAutomountDevice(udi, AutomounterSettings::Login))
+                    if (m_loginForced[udi] || m_settings->shouldAutomountDevice(udi, AutomounterSettings::Login))
                         return i18n("This device will be automatically mounted at login.");
                     return i18n("This device will not be automatically mounted at login.");
                 }
@@ -289,7 +332,7 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
                 case Qt::CheckStateRole:
                     return m_attachedForced[udi] ? Qt::Checked : Qt::Unchecked;
                 case Qt::ToolTipRole:
-                    if (m_attachedForced[udi] || AutomounterSettings::shouldAutomountDevice(udi, AutomounterSettings::Attach))
+                    if (m_attachedForced[udi] || m_settings->shouldAutomountDevice(udi, AutomounterSettings::Attach))
                         return i18n("This device will be automatically mounted when attached.");
                     return i18n("This device will not be automatically mounted when attached.");
                 }
@@ -325,6 +368,28 @@ int DeviceModel::rowCount(const QModelIndex &parent) const
 
 int DeviceModel::columnCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return 3;
 }
+
+void DeviceModel::setAutomaticMountOnLogin(bool automaticLogin)
+{
+    if (m_automaticLogin != automaticLogin) {
+        m_automaticLogin = automaticLogin;
+        for (int parent = 0; parent < rowCount(); parent++) {
+            const auto parentIndex = index(parent, 0);
+            emit dataChanged(index(0, 1, parentIndex), index(rowCount(parentIndex), 1, parentIndex));
+        }
+    }
+}
+
+void DeviceModel::setAutomaticMountOnPlugin(bool automaticAttached)
+{
+    if (m_automaticAttached != automaticAttached) {
+        m_automaticAttached = automaticAttached;
+        for (int parent = 0; parent < rowCount(); parent++) {
+            const auto parentIndex = index(parent, 0);
+            emit dataChanged(index(0, 2, parentIndex), index(rowCount(parentIndex), 2, parentIndex));
+        }
+    }
+}
